################### vonMises Package ########################
##														   ##
##					  Created by:						   ##
##			Vedant Mehta (vedantmehta08@gmail.com)         ##
##		 Kanchan Satpute (kanchansatpute09@gmail.com)      ##
##														   ##
##														   ##
#############################################################

This package contains the following functions:
1. rvonmises - Generate random deviates from vonMises distribution
2. dvonmises - Computes probability density on the basis of vonMises’ probability density function
3. pvonmises - Computes cumulative probability on the basis vonMises’ cumulative distribution
4. qvonmises - Generates quantiles i.e., basically the inverse of vonMises cumulative distribution function


